@@ -20,7 +20,6 @@ const FixSwhSourceMapsPlugin = require('./webpack-plugins/fix-swh-source-maps-we
 const CopyWebpackPlugin = require('copy-webpack-plugin');
 const GenerateWebLabelsPlugin = require('./webpack-plugins/generate-weblabels-webpack-plugin');
 const ProgressBarPlugin = require('progress-bar-webpack-plugin');
-const FixWebpackStatsFormatPlugin = require('./webpack-plugins/fix-webpack-stats-format-plugin');
 const DumpHighlightjsLanguagesDataPlugin = require('./webpack-plugins/dump-highlightjs-languages-data-plugin');
 
 // are we running webpack-dev-server ?
@@ -46,7 +45,7 @@ fs.readdirSync(bundlesDir).forEach(file => {
 });
 
 // common loaders for css related assets (css, sass)
-let cssLoaders = [
+const cssLoaders = [
   MiniCssExtractPlugin.loader,
   {
     loader: 'cache-loader'
@@ -104,6 +103,7 @@ module.exports = {
   // webpack-dev-server configuration
   devServer: {
     clientLogLevel: 'warning',
+    host: '0.0.0.0',
     port: devServerPort,
     publicPath: devServerPublicPath,
     // enable to serve static assets not managed by webpack
@@ -123,7 +123,8 @@ module.exports = {
       errors: true
     },
     // workaround for https://github.com/webpack/webpack-dev-server/issues/2692
-    injectClient: false
+    injectClient: false,
+    transportMode: 'ws'
   },
   // set entries to the bundles we want to produce
   entry: bundles,
@@ -343,6 +344,11 @@ module.exports = {
             outputPath: 'img/thirdParty/'
           }
         }]
+      },
+      {
+        test: /\.ya?ml$/,
+        type: 'json',
+        use: 'yaml-loader'
       }
     ],
     // tell webpack to not parse already minified files to speedup build process
@@ -359,8 +365,7 @@ module.exports = {
     }),
     // needed in order to use django_webpack_loader
     new BundleTracker({
-      path: path.resolve('./static/'),
-      filename: 'webpack-stats.json'
+      filename: './static/webpack-stats.json'
     }),
     // for generating the robots.txt file
     new RobotstxtPlugin({
@@ -459,7 +464,6 @@ module.exports = {
       format: chalk.cyan.bold('webpack build of swh-web assets') + ' [:bar] ' + chalk.green.bold(':percent') + ' (:elapsed seconds)',
       width: 50
     }),
-    new FixWebpackStatsFormatPlugin(),
     new DumpHighlightjsLanguagesDataPlugin()
   ],
   // webpack optimizations
