@@ -5,47 +5,128 @@
  * See top-level LICENSE file for more information
  */
 
-import {csrfPost, handleFetchError, isGitRepoUrl, htmlAlert, removeUrlFragment} from 'utils/functions';
+import {csrfPost, handleFetchError, isGitRepoUrl, htmlAlert, removeUrlFragment,
+        getCanonicalOriginURL} from 'utils/functions';
 import {swhSpinnerSrc} from 'utils/constants';
+import artifactFormRowTemplate from './artifact-form-row.ejs';
 
 let saveRequestsTable;
 
-function originSaveRequest(originType, originUrl,
-                           acceptedCallback, pendingCallback, errorCallback) {
-  let addSaveOriginRequestUrl = Urls.api_1_save_origin(originType, originUrl);
+async function originSaveRequest(
+  originType, originUrl, extraData,
+  acceptedCallback, pendingCallback, errorCallback
+) {
+  // Actually trigger the origin save request
+  const addSaveOriginRequestUrl = Urls.api_1_save_origin(originType, originUrl);
   $('.swh-processing-save-request').css('display', 'block');
-  csrfPost(addSaveOriginRequestUrl)
-    .then(handleFetchError)
-    .then(response => response.json())
-    .then(data => {
-      $('.swh-processing-save-request').css('display', 'none');
-      if (data.save_request_status === 'accepted') {
-        acceptedCallback();
-      } else {
-        pendingCallback();
-      }
-    })
-    .catch(response => {
-      $('.swh-processing-save-request').css('display', 'none');
-      response.json().then(errorData => {
-        errorCallback(response.status, errorData);
-      });
-    });
+  let headers = {};
+  let body = null;
+  if (extraData !== {}) {
+    body = JSON.stringify(extraData);
+    headers = {
+      'Content-Type': 'application/json'
+    };
+  };
+
+  try {
+    const response = await csrfPost(addSaveOriginRequestUrl, headers, body);
+    handleFetchError(response);
+    const data = await response.json();
+    $('.swh-processing-save-request').css('display', 'none');
+    if (data.save_request_status === 'accepted') {
+      acceptedCallback();
+    } else {
+      pendingCallback();
+    }
+  } catch (response) {
+    $('.swh-processing-save-request').css('display', 'none');
+    const errorData = await response.json();
+    errorCallback(response.status, errorData);
+  };
 }
 
+function addArtifactVersionAutofillHandler(formId) {
+  // autofill artifact version input with the filename from
+  // the artifact url without extensions
+  $(`#swh-input-artifact-url-${formId}`).on('input', function(event) {
+    const artifactUrl = $(this).val().trim();
+    let filename = artifactUrl.split('/').slice(-1)[0];
+    if (filename !== artifactUrl) {
+      filename = filename.replace(/tar.*$/, 'tar');
+      const filenameNoExt = filename.split('.').slice(0, -1).join('.');
+      const artifactVersion = $(`#swh-input-artifact-version-${formId}`);
+      if (filenameNoExt !== filename) {
+        artifactVersion.val(filenameNoExt);
+      }
+    }
+  });
+}
+
+export function maybeRequireExtraInputs() {
+  // Read the actual selected value and depending on the origin type, display some extra
+  // inputs or hide them. This makes the extra inputs disabled when not displayed.
+  const originType = $('#swh-input-visit-type').val();
+  let display = 'none';
+  let disabled = true;
+
+  if (originType === 'archives') {
+    display = 'flex';
+    disabled = false;
+  }
+  $('.swh-save-origin-archives-form').css('display', display);
+  if (!disabled) {
+    // help paragraph must have block display for proper rendering
+    $('#swh-save-origin-archives-help').css('display', 'block');
+  }
+  $('.swh-save-origin-archives-form .form-control').prop('disabled', disabled);
+
+  if (originType === 'archives' && $('.swh-save-origin-archives-form').length === 1) {
+    // insert first artifact row when the archives visit type is selected for the first time
+    $('.swh-save-origin-archives-form').last().after(
+      artifactFormRowTemplate({deletableRow: false, formId: 0}));
+    addArtifactVersionAutofillHandler(0);
+  }
+}
+
+export function addArtifactFormRow() {
+  const formId = $('.swh-save-origin-artifact-form').length;
+  $('.swh-save-origin-artifact-form').last().after(
+    artifactFormRowTemplate({
+      deletableRow: true,
+      formId: formId
+    })
+  );
+  addArtifactVersionAutofillHandler(formId);
+}
+
+export function deleteArtifactFormRow(event) {
+  $(event.target).closest('.swh-save-origin-artifact-form').remove();
+}
+
+const userRequestsFilterCheckbox = `
+<div class="custom-control custom-checkbox swhid-option">
+  <input class="custom-control-input" value="option-user-requests-filter" type="checkbox"
+         id="swh-save-requests-user-filter">
+  <label class="custom-control-label font-weight-normal" for="swh-save-requests-user-filter">
+    show only your own requests
+  </label>
+</div>
+`;
+
 export function initOriginSave() {
 
-  $(document).ready(() => {
+  $(document).ready(async() => {
 
     $.fn.dataTable.ext.errMode = 'none';
 
-    fetch(Urls.origin_save_types_list())
-      .then(response => response.json())
-      .then(data => {
-        for (let originType of data) {
-          $('#swh-input-visit-type').append(`<option value="${originType}">${originType}</option>`);
-        }
-      });
+    const response = await fetch(Urls.origin_save_types_list());
+    const data = await response.json();
+
+    for (const originType of data) {
+      $('#swh-input-visit-type').append(`<option value="${originType}">${originType}</option>`);
+    }
+    // set git as the default value as before
+    $('#swh-input-visit-type').val('git');
 
     saveRequestsTable = $('#swh-origin-save-requests')
       .on('error.dt', (e, settings, techNote, message) => {
@@ -58,15 +139,36 @@ export function initOriginSave() {
         language: {
           processing: `<img src="${swhSpinnerSrc}"></img>`
         },
-        ajax: Urls.origin_save_requests_list('all'),
+        ajax: {
+          url: Urls.origin_save_requests_list('all'),
+          data: (d) => {
+            if (swh.webapp.isUserLoggedIn() && $('#swh-save-requests-user-filter').prop('checked')) {
+              d.user_requests_only = '1';
+            }
+          }
+        },
         searchDelay: 1000,
+        // see https://datatables.net/examples/advanced_init/dom_toolbar.html and the comments section
+        // this option customizes datatables UI components by adding an extra checkbox above the table
+        // while keeping bootstrap layout
+        dom: '<"row"<"col-sm-3"l><"col-sm-6 text-left user-requests-filter"><"col-sm-3"f>>' +
+             '<"row"<"col-sm-12"tr>>' +
+             '<"row"<"col-sm-5"i><"col-sm-7"p>>',
+        fnInitComplete: function() {
+          if (swh.webapp.isUserLoggedIn()) {
+            $('div.user-requests-filter').html(userRequestsFilterCheckbox);
+            $('#swh-save-requests-user-filter').on('change', () => {
+              saveRequestsTable.draw();
+            });
+          }
+        },
         columns: [
           {
             data: 'save_request_date',
             name: 'request_date',
             render: (data, type, row) => {
               if (type === 'display') {
-                let date = new Date(data);
+                const date = new Date(data);
                 return date.toLocaleString();
               }
               return data;
@@ -92,7 +194,8 @@ export function initOriginSave() {
                 } else {
                   html += sanitizedURL;
                 }
-                html += `&nbsp;<a href="${sanitizedURL}"><i class="mdi mdi-open-in-new" aria-hidden="true"></i></a>`;
+                html += `&nbsp;<a href="${sanitizedURL}" target="_blank" rel="noopener noreferrer">` +
+                  '<i class="mdi mdi-open-in-new" aria-hidden="true"></i></a>';
                 return html;
               }
               return data;
@@ -156,40 +259,54 @@ export function initOriginSave() {
       $('.swh-save-request-info').popover('dispose');
     });
 
-    let saveRequestAcceptedAlert = htmlAlert(
+    const saveRequestAcceptedAlert = htmlAlert(
       'success',
       'The "save code now" request has been accepted and will be processed as soon as possible.',
       true
     );
 
-    let saveRequestPendingAlert = htmlAlert(
+    const saveRequestPendingAlert = htmlAlert(
       'warning',
       'The "save code now" request has been put in pending state and may be accepted for processing after manual review.',
       true
     );
 
-    let saveRequestRateLimitedAlert = htmlAlert(
+    const saveRequestRateLimitedAlert = htmlAlert(
       'danger',
       'The rate limit for "save code now" requests has been reached. Please try again later.',
       true
     );
 
-    let saveRequestUnknownErrorAlert = htmlAlert(
+    const saveRequestUnknownErrorAlert = htmlAlert(
       'danger',
       'An unexpected error happened when submitting the "save code now request".',
       true
     );
 
-    $('#swh-save-origin-form').submit(event => {
+    $('#swh-save-origin-form').submit(async event => {
       event.preventDefault();
       event.stopPropagation();
       $('.alert').alert('close');
       if (event.target.checkValidity()) {
         $(event.target).removeClass('was-validated');
-        let originType = $('#swh-input-visit-type').val();
+        const originType = $('#swh-input-visit-type').val();
         let originUrl = $('#swh-input-origin-url').val();
 
-        originSaveRequest(originType, originUrl,
+        originUrl = await getCanonicalOriginURL(originUrl);
+
+        // read the extra inputs for the 'archives' type
+        const extraData = {};
+        if (originType === 'archives') {
+          extraData['archives_data'] = [];
+          for (let i = 0; i < $('.swh-save-origin-artifact-form').length; ++i) {
+            extraData['archives_data'].push({
+              'artifact_url': $(`#swh-input-artifact-url-${i}`).val(),
+              'artifact_version': $(`#swh-input-artifact-version-${i}`).val()
+            });
+          }
+        }
+
+        originSaveRequest(originType, originUrl, extraData,
                           () => $('#swh-origin-save-request-status').html(saveRequestAcceptedAlert),
                           () => $('#swh-origin-save-request-status').html(saveRequestPendingAlert),
                           (statusCode, errorData) => {
@@ -217,10 +334,10 @@ export function initOriginSave() {
     });
 
     $('#swh-input-origin-url').on('input', function(event) {
-      let originUrl = $(this).val().trim();
+      const originUrl = $(this).val().trim();
       $(this).val(originUrl);
       $('#swh-input-visit-type option').each(function() {
-        let val = $(this).val();
+        const val = $(this).val();
         if (val && originUrl.includes(val)) {
           $(this).prop('selected', true);
         }
@@ -236,7 +353,7 @@ export function initOriginSave() {
 }
 
 export function validateSaveOriginUrl(input) {
-  let originType = $('#swh-input-visit-type').val();
+  const originType = $('#swh-input-visit-type').val();
   let originUrl = null;
   let validUrl = true;
 
@@ -247,7 +364,7 @@ export function validateSaveOriginUrl(input) {
   }
 
   if (validUrl) {
-    let allowedProtocols = ['http:', 'https:', 'svn:', 'git:'];
+    const allowedProtocols = ['http:', 'https:', 'svn:', 'git:'];
     validUrl = (
       allowedProtocols.find(protocol => protocol === originUrl.protocol) !== undefined
     );
@@ -285,25 +402,25 @@ export function validateSaveOriginUrl(input) {
 
 export function initTakeNewSnapshot() {
 
-  let newSnapshotRequestAcceptedAlert = htmlAlert(
+  const newSnapshotRequestAcceptedAlert = htmlAlert(
     'success',
     'The "take new snapshot" request has been accepted and will be processed as soon as possible.',
     true
   );
 
-  let newSnapshotRequestPendingAlert = htmlAlert(
+  const newSnapshotRequestPendingAlert = htmlAlert(
     'warning',
     'The "take new snapshot" request has been put in pending state and may be accepted for processing after manual review.',
     true
   );
 
-  let newSnapshotRequestRateLimitAlert = htmlAlert(
+  const newSnapshotRequestRateLimitAlert = htmlAlert(
     'danger',
     'The rate limit for "take new snapshot" requests has been reached. Please try again later.',
     true
   );
 
-  let newSnapshotRequestUnknownErrorAlert = htmlAlert(
+  const newSnapshotRequestUnknownErrorAlert = htmlAlert(
     'danger',
     'An unexpected error happened when submitting the "save code now request".',
     true
@@ -314,10 +431,11 @@ export function initTakeNewSnapshot() {
       event.preventDefault();
       event.stopPropagation();
 
-      let originType = $('#swh-input-visit-type').val();
-      let originUrl = $('#swh-input-origin-url').val();
+      const originType = $('#swh-input-visit-type').val();
+      const originUrl = $('#swh-input-origin-url').val();
+      const extraData = {};
 
-      originSaveRequest(originType, originUrl,
+      originSaveRequest(originType, originUrl, extraData,
                         () => $('#swh-take-new-snapshot-request-status').html(newSnapshotRequestAcceptedAlert),
                         () => $('#swh-take-new-snapshot-request-status').html(newSnapshotRequestPendingAlert),
                         (statusCode, errorData) => {
@@ -347,7 +465,7 @@ export function formatValuePerType(type, value) {
   return value === null ? null : mapFormatPerTypeFn[type](value);
 }
 
-export function displaySaveRequestInfo(event, saveRequestId) {
+export async function displaySaveRequestInfo(event, saveRequestId) {
   event.stopPropagation();
   const saveRequestTaskInfoUrl = Urls.origin_save_task_info(saveRequestId);
   // close popover when clicking again on the info icon
@@ -382,57 +500,56 @@ export function displaySaveRequestInfo(event, saveRequestId) {
   });
 
   $(event.target).popover('show');
-  fetch(saveRequestTaskInfoUrl)
-    .then(response => response.json())
-    .then(saveRequestTaskInfo => {
-      let content;
-      if ($.isEmptyObject(saveRequestTaskInfo)) {
-        content = 'Not available';
-      } else {
-        let saveRequestInfo = [];
-        const taskData = {
-          'Type': ['raw', 'type'],
-          'Visit status': ['raw', 'visit_status'],
-          'Arguments': ['json', 'arguments'],
-          'Id': ['raw', 'id'],
-          'Backend id': ['raw', 'backend_id'],
-          'Scheduling date': ['date', 'scheduled'],
-          'Start date': ['date', 'started'],
-          'Completion date': ['date', 'ended'],
-          'Duration': ['duration', 'duration'],
-          'Runner': ['raw', 'worker'],
-          'Log': ['raw', 'message']
-        };
-        for (const [title, [type, property]] of Object.entries(taskData)) {
-          if (saveRequestTaskInfo.hasOwnProperty(property)) {
-            saveRequestInfo.push({
-              key: title,
-              value: formatValuePerType(type, saveRequestTaskInfo[property])
-            });
-          }
-        }
-        content = '<table class="table"><tbody>';
-        for (let info of saveRequestInfo) {
-          content +=
+  const response = await fetch(saveRequestTaskInfoUrl);
+  const saveRequestTaskInfo = await response.json();
+
+  let content;
+  if ($.isEmptyObject(saveRequestTaskInfo)) {
+    content = 'Not available';
+  } else {
+    const saveRequestInfo = [];
+    const taskData = {
+      'Type': ['raw', 'type'],
+      'Visit status': ['raw', 'visit_status'],
+      'Arguments': ['json', 'arguments'],
+      'Id': ['raw', 'id'],
+      'Backend id': ['raw', 'backend_id'],
+      'Scheduling date': ['date', 'scheduled'],
+      'Start date': ['date', 'started'],
+      'Completion date': ['date', 'ended'],
+      'Duration': ['duration', 'duration'],
+      'Runner': ['raw', 'worker'],
+      'Log': ['raw', 'message']
+    };
+    for (const [title, [type, property]] of Object.entries(taskData)) {
+      if (saveRequestTaskInfo.hasOwnProperty(property)) {
+        saveRequestInfo.push({
+          key: title,
+          value: formatValuePerType(type, saveRequestTaskInfo[property])
+        });
+      }
+    }
+    content = '<table class="table"><tbody>';
+    for (const info of saveRequestInfo) {
+      content +=
             `<tr>
               <th class="swh-metadata-table-row swh-metadata-table-key">${info.key}</th>
               <td class="swh-metadata-table-row swh-metadata-table-value">
                 <pre>${info.value}</pre>
               </td>
             </tr>`;
-        }
-        content += '</tbody></table>';
-      }
-      $('.swh-popover').html(content);
-      $(event.target).popover('update');
-    });
+    }
+    content += '</tbody></table>';
+  }
+  $('.swh-popover').html(content);
+  $(event.target).popover('update');
 }
 
 export function fillSaveRequestFormAndScroll(visitType, originUrl) {
   $('#swh-input-origin-url').val(originUrl);
   let originTypeFound = false;
   $('#swh-input-visit-type option').each(function() {
-    let val = $(this).val();
+    const val = $(this).val();
     if (val && originUrl.includes(val)) {
       $(this).prop('selected', true);
       originTypeFound = true;
@@ -440,7 +557,7 @@ export function fillSaveRequestFormAndScroll(visitType, originUrl) {
   });
   if (!originTypeFound) {
     $('#swh-input-visit-type option').each(function() {
-      let val = $(this).val();
+      const val = $(this).val();
       if (val === visitType) {
         $(this).prop('selected', true);
       }
