@@ -5,7 +5,7 @@
 
 from swh.web.api.apidoc import api_doc, format_docstring
 from swh.web.api.apiurls import api_route
-from swh.web.auth.utils import SWH_AMBASSADOR_PERMISSION
+from swh.web.auth.utils import privileged_user
 from swh.web.common.origin_save import (
     create_save_origin_request,
     get_save_origin_requests,
@@ -83,11 +83,15 @@ def api_save_origin(request, visit_type, origin_url):
 
     """
 
+    data = request.data or {}
     if request.method == "POST":
-        bypass_pending_review = request.user.is_authenticated and request.user.has_perm(
-            SWH_AMBASSADOR_PERMISSION
+        sor = create_save_origin_request(
+            visit_type,
+            origin_url,
+            privileged_user(request),
+            user_id=request.user.id,
+            **data,
         )
-        sor = create_save_origin_request(visit_type, origin_url, bypass_pending_review)
         del sor["id"]
     else:
         sor = get_save_origin_requests(visit_type, origin_url)
