@@ -161,6 +161,7 @@ def origin_branches_browse(request):
         origin_url=request.GET.get("origin_url"),
         snapshot_id=request.GET.get("snapshot"),
         timestamp=request.GET.get("timestamp"),
+        branch_name_include=request.GET.get("name_include"),
     )
 
 
@@ -201,6 +202,7 @@ def origin_releases_browse(request):
         origin_url=request.GET.get("origin_url"),
         snapshot_id=request.GET.get("snapshot"),
         timestamp=request.GET.get("timestamp"),
+        release_name_include=request.GET.get("name_include"),
     )
 
 
