@@ -14,6 +14,7 @@ import docutils.parsers.rst
 import docutils.utils
 from docutils.writers.html5_polyglot import HTMLTranslator, Writer
 from iso8601 import ParseError, parse_date
+from pkg_resources import get_distribution
 from prometheus_client.registry import CollectorRegistry
 
 from django.http import HttpRequest, QueryDict
@@ -266,12 +267,14 @@ def context_processor(request):
         "site_base_url": site_base_url,
         "DJANGO_SETTINGS_MODULE": os.environ["DJANGO_SETTINGS_MODULE"],
         "status": config["status"],
+        "swh_web_dev": "localhost" in site_base_url,
         "swh_web_staging": any(
             [
                 server_name in site_base_url
                 for server_name in config["staging_server_names"]
             ]
         ),
+        "swh_web_version": get_distribution("swh.web").version,
         "visit_types": ORIGIN_VISIT_TYPES,
     }
 
@@ -333,6 +336,8 @@ def rst_to_html(rst: str) -> str:
     """
     settings = {
         "initial_header_level": 2,
+        "halt_level": 4,
+        "traceback": True,
     }
     pp = publish_parts(rst, writer=_HTML_WRITER, settings_overrides=settings)
     return f'<div class="swh-rst">{pp["html_body"]}</div>'
