@@ -3,9 +3,10 @@
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
+from prometheus_client.exposition import CONTENT_TYPE_LATEST, generate_latest
+
 from django.http import HttpResponse
 
-from prometheus_client.exposition import generate_latest, CONTENT_TYPE_LATEST
 from swh.web.common.origin_save import compute_save_requests_metrics
 from swh.web.common.utils import SWH_WEB_METRICS_REGISTRY
 
