@@ -9,6 +9,7 @@ from django.db.models import Q
 from django.http import JsonResponse
 from django.shortcuts import render
 
+from swh.web.auth.utils import privileged_user
 from swh.web.common.models import SaveOriginRequest
 from swh.web.common.origin_save import (
     get_savable_visit_types,
@@ -20,12 +21,15 @@ def _origin_save_view(request):
     return render(
         request,
         "misc/origin-save.html",
-        {"heading": ("Request the saving of a software origin into " "the archive")},
+        {"heading": ("Request the saving of a software origin into the archive")},
     )
 
 
-def _visit_save_types_list(request):
-    visit_types = get_savable_visit_types()
+def _visit_save_types_list(request) -> JsonResponse:
+    """Return the list of supported visit types as json response
+
+    """
+    visit_types = get_savable_visit_types(privileged_user(request))
     return JsonResponse(visit_types, safe=False)
 
 
@@ -61,6 +65,12 @@ def _origin_save_requests_list(request, status):
             | Q(origin_url__icontains=search_value)
         )
 
+    if (
+        int(request.GET.get("user_requests_only", "0"))
+        and request.user.is_authenticated
+    ):
+        save_requests = save_requests.filter(user_ids__contains=f'"{request.user.id}"')
+
     table_data["recordsFiltered"] = save_requests.count()
     paginator = Paginator(save_requests, length)
     table_data["data"] = [sor.to_dict() for sor in paginator.page(page).object_list]
