@@ -995,12 +995,12 @@ def test_lookup_origin_single_slash_after_protocol(archive_data):
 @given(origin(), new_origin())
 def test_lookup_origins_get_by_sha1s(origin, unknown_origin):
     hasher = hashlib.sha1()
-    hasher.update(origin["url"].encode("ascii"))
+    hasher.update(origin["url"].encode("utf-8"))
     origin_info = OriginInfo(url=origin["url"])
     origin_sha1 = hasher.hexdigest()
 
     hasher = hashlib.sha1()
-    hasher.update(unknown_origin.url.encode("ascii"))
+    hasher.update(unknown_origin.url.encode("utf-8"))
     unknown_origin_sha1 = hasher.hexdigest()
 
     origins = list(archive.lookup_origins_by_sha1s([origin_sha1]))
@@ -1069,6 +1069,34 @@ def test_lookup_snapshot_alias(snapshot):
     assert resolved_alias["target"] is not None
 
 
+@given(revision())
+def test_lookup_snapshot_missing(revision):
+    with pytest.raises(NotFoundExc):
+        archive.lookup_snapshot(revision)
+
+
+@given(revision())
+def test_lookup_snapshot_empty_branch_list(archive_data, revision):
+    rev_id = hash_to_bytes(revision)
+    snapshot = Snapshot(
+        branches={
+            b"refs/heads/master": SnapshotBranch(
+                target=rev_id, target_type=TargetType.REVISION,
+            ),
+        },
+    )
+    archive_data.snapshot_add([snapshot])
+
+    # FIXME; This test will change once the inconsistency in storage is fixed
+    # postgres backend returns None in case of a missing branch whereas the
+    # in-memory implementation (used in tests) returns a data structure;
+    # hence the inconsistency
+    branches = archive.lookup_snapshot(
+        hash_to_hex(snapshot.id), branch_name_include_substring="non-existing",
+    )["branches"]
+    assert not branches
+
+
 @given(revision())
 def test_lookup_snapshot_branch_names_filtering(archive_data, revision):
     rev_id = hash_to_bytes(revision)
