@@ -34,6 +34,7 @@ from swh.web.tests.data import random_sha1
 from swh.web.tests.strategies import (
     content,
     directory,
+    directory_with_files,
     directory_with_subdirs,
     origin,
     origin_with_multiple_visits,
@@ -95,11 +96,12 @@ def test_resolve_swhid_legacy(content, directory, release, revision, snapshot):
             f"browse-{obj_type}", url_args=url_args, query_params=query_params
         )
 
-        resolved_swhid = resolve_swhid(swhid, query_params)
+        for swhid_ in (swhid, swhid.upper()):
+            resolved_swhid = resolve_swhid(swhid_, query_params)
 
-        assert isinstance(resolved_swhid["swhid_parsed"], QualifiedSWHID)
-        assert str(resolved_swhid["swhid_parsed"]) == swhid
-        assert resolved_swhid["browse_url"] == browse_url
+            assert isinstance(resolved_swhid["swhid_parsed"], QualifiedSWHID)
+            assert str(resolved_swhid["swhid_parsed"]) == swhid
+            assert resolved_swhid["browse_url"] == browse_url
 
     with pytest.raises(BadInputExc, match="'ori' is not a valid ObjectType"):
         resolve_swhid(f"swh:1:ori:{random_sha1()}")
@@ -115,10 +117,10 @@ def test_get_swhid(content, directory, release, revision, snapshot):
         (SNAPSHOT, snapshot),
     ):
         swhid = gen_swhid(obj_type, obj_id)
-        swh_parsed_swhid = get_swhid(swhid)
-
-        assert isinstance(swh_parsed_swhid, QualifiedSWHID)
-        assert str(swh_parsed_swhid) == swhid
+        for swhid_ in (swhid, swhid.upper()):
+            swh_parsed_swhid = get_swhid(swhid_)
+            assert isinstance(swh_parsed_swhid, QualifiedSWHID)
+            assert str(swh_parsed_swhid) == swhid.lower()
 
     with pytest.raises(BadInputExc, match="Error when parsing identifier"):
         get_swhid("foo")
@@ -191,14 +193,18 @@ def test_get_swhids_info_directory_context(archive_data, directory):
         swh_objects_info, snapshot_context=None, extra_context=extra_context,
     )
 
-    swhid_dir_parsed = get_swhid(swhids[0]["swhid_with_context"])
+    swhid_lower = swhids[0]["swhid_with_context"]
+    swhid_upper = swhid_lower.replace(swhids[0]["swhid"], swhids[0]["swhid"].upper())
 
-    anchor = gen_swhid(DIRECTORY, directory)
+    for swhid in (swhid_lower, swhid_upper):
+        swhid_dir_parsed = get_swhid(swhid)
 
-    assert swhid_dir_parsed.qualifiers() == {
-        "anchor": anchor,
-        "path": dir_subdir_path,
-    }
+        anchor = gen_swhid(DIRECTORY, directory)
+
+        assert swhid_dir_parsed.qualifiers() == {
+            "anchor": anchor,
+            "path": dir_subdir_path,
+        }
 
     if dir_subdir_files:
         swhid_cnt_parsed = get_swhid(swhids[1]["swhid_with_context"])
@@ -235,13 +241,18 @@ def test_get_swhids_info_revision_context(archive_data, revision):
     )
 
     assert swhids[0]["context"] == {}
-    swhid_dir_parsed = get_swhid(swhids[1]["swhid_with_context"])
 
-    anchor = gen_swhid(REVISION, revision)
+    swhid_lower = swhids[1]["swhid_with_context"]
+    swhid_upper = swhid_lower.replace(swhids[1]["swhid"], swhids[1]["swhid"].upper())
 
-    assert swhid_dir_parsed.qualifiers() == {
-        "anchor": anchor,
-    }
+    for swhid in (swhid_lower, swhid_upper):
+        swhid_dir_parsed = get_swhid(swhid)
+
+        anchor = gen_swhid(REVISION, revision)
+
+        assert swhid_dir_parsed.qualifiers() == {
+            "anchor": anchor,
+        }
 
     if dir_entry["type"] == "file":
         swhid_cnt_parsed = get_swhid(swhids[2]["swhid_with_context"])
@@ -573,26 +584,29 @@ def _check_resolved_swhid_browse_url(
     if lines:
         obj_context["lines"] = lines
 
-    obj_swhid = gen_swhid(object_type, object_id, metadata=obj_context)
+    obj_core_swhid = gen_swhid(object_type, object_id)
+    obj_swhid_lower = gen_swhid(object_type, object_id, metadata=obj_context)
+    obj_swhid_upper = obj_swhid_lower.replace(obj_core_swhid, obj_core_swhid.upper(), 1)
 
-    obj_swhid_resolved = resolve_swhid(obj_swhid)
+    for obj_swhid in (obj_swhid_lower, obj_swhid_upper):
+        obj_swhid_resolved = resolve_swhid(obj_swhid)
 
-    url_args = {"sha1_git": object_id}
-    if object_type == CONTENT:
-        url_args = {"query_string": f"sha1_git:{object_id}"}
-    elif object_type == SNAPSHOT:
-        url_args = {"snapshot_id": object_id}
+        url_args = {"sha1_git": object_id}
+        if object_type == CONTENT:
+            url_args = {"query_string": f"sha1_git:{object_id}"}
+        elif object_type == SNAPSHOT:
+            url_args = {"snapshot_id": object_id}
 
-    expected_url = reverse(
-        f"browse-{object_type}", url_args=url_args, query_params=query_params,
-    )
-    if lines:
-        lines_number = lines.split("-")
-        expected_url += f"#L{lines_number[0]}"
-        if len(lines_number) > 1:
-            expected_url += f"-L{lines_number[1]}"
+        expected_url = reverse(
+            f"browse-{object_type}", url_args=url_args, query_params=query_params,
+        )
+        if lines:
+            lines_number = lines.split("-")
+            expected_url += f"#L{lines_number[0]}"
+            if len(lines_number) > 1:
+                expected_url += f"-L{lines_number[1]}"
 
-    assert obj_swhid_resolved["browse_url"] == expected_url
+        assert obj_swhid_resolved["browse_url"] == expected_url
 
 
 @given(directory())
@@ -635,3 +649,91 @@ def test_resolve_swhid_with_malformed_origin_url(archive_data, directory):
     swhid = gen_swhid(DIRECTORY, directory, metadata={"origin": malformed_origin_url})
     resolved_swhid = resolve_swhid(swhid)
     assert origin_url in resolved_swhid["browse_url"]
+
+
+@given(revision())
+def test_resolve_dir_entry_swhid_with_anchor_revision(archive_data, revision):
+    revision_data = archive_data.revision_get(revision)
+    directory = revision_data["directory"]
+    dir_content = archive_data.directory_ls(directory)
+    dir_entry = random.choice(dir_content)
+
+    rev_swhid = gen_swhid(REVISION, revision)
+
+    if dir_entry["type"] == "rev":
+        return
+
+    if dir_entry["type"] == "file":
+        swhid = gen_swhid(
+            CONTENT,
+            dir_entry["checksums"]["sha1_git"],
+            metadata={"anchor": rev_swhid, "path": f"/{dir_entry['name']}"},
+        )
+
+    else:
+        swhid = gen_swhid(
+            DIRECTORY,
+            dir_entry["target"],
+            metadata={"anchor": rev_swhid, "path": f"/{dir_entry['name']}/"},
+        )
+
+    browse_url = reverse(
+        "browse-revision",
+        url_args={"sha1_git": revision},
+        query_params={"path": dir_entry["name"]},
+    )
+
+    resolved_swhid = resolve_swhid(swhid)
+
+    assert resolved_swhid["browse_url"] == browse_url
+
+
+@given(directory_with_subdirs())
+def test_resolve_dir_entry_swhid_with_anchor_directory(archive_data, directory):
+    dir_content = archive_data.directory_ls(directory)
+    dir_entry = random.choice(
+        [entry for entry in dir_content if entry["type"] == "dir"]
+    )
+
+    dir_swhid = gen_swhid(DIRECTORY, directory)
+
+    swhid = gen_swhid(
+        DIRECTORY,
+        dir_entry["target"],
+        metadata={"anchor": dir_swhid, "path": f"/{dir_entry['name']}/"},
+    )
+    browse_url = reverse(
+        "browse-directory",
+        url_args={"sha1_git": directory},
+        query_params={"path": f"{dir_entry['name']}"},
+    )
+
+    resolved_swhid = resolve_swhid(swhid)
+
+    assert resolved_swhid["browse_url"] == browse_url
+
+
+@given(directory_with_files())
+def test_resolve_file_entry_swhid_with_anchor_directory(archive_data, directory):
+    dir_content = archive_data.directory_ls(directory)
+    file_entry = random.choice(
+        [entry for entry in dir_content if entry["type"] == "file"]
+    )
+
+    dir_swhid = gen_swhid(DIRECTORY, directory)
+
+    sha1_git = file_entry["checksums"]["sha1_git"]
+    swhid = gen_swhid(
+        CONTENT,
+        sha1_git,
+        metadata={"anchor": dir_swhid, "path": f"/{file_entry['name']}"},
+    )
+    browse_url = reverse(
+        "browse-content",
+        url_args={"query_string": f"sha1_git:{sha1_git}"},
+        query_params={"path": f"{directory}/{file_entry['name']}"},
+    )
+
+    resolved_swhid = resolve_swhid(swhid)
+
+    assert resolved_swhid["browse_url"] == browse_url
